Number

Trait Number 

pub trait Number:
    Num
    + PartialOrd
    + Debug
    + Clone
    + Copy { }
Basic requirements for a type to be usable by solver.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> Number for T
where T: Num + PartialOrd + Debug + Clone + Copy,

Anything that implements the required traits already implements Number.